#
# spec file for package liferea
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           liferea
Version:        1.14.6
Release:        1.3
Summary:        Linux Feed Reader
License:        GPL-2.0-only
Group:          Productivity/Other
URL:            https://lzone.de/liferea/
Source0:        https://github.com/lwindolf/liferea/releases/download/v%{version}/%{name}-%{version}.tar.bz2
# PATCH-FEATURE-OPENSUSE liferea-opensuse-feeds.patch -- Add openSUSE feeds to default feeds
Patch0:         liferea-opensuse-feeds.patch
# PATCH-FIX-UPSTREAM
Patch1:         https://github.com/lwindolf/liferea/commit/be8ef494.patch
BuildRequires:  appstream-glib
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  intltool >= 0.40.0
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0) >= 2.28.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.4.0
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpeas-1.0) >= 1.0.0
BuildRequires:  pkgconfig(libpeas-gtk-1.0) >= 1.0.0
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.28.2
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6.27
BuildRequires:  pkgconfig(libxslt) >= 1.1.19
BuildRequires:  pkgconfig(pango) >= 1.4.0
BuildRequires:  pkgconfig(sqlite3) >= 3.7.0
BuildRequires:  pkgconfig(webkit2gtk-4.0)
Requires:       dbus-1 >= 0.30
Requires:       python3-cairo
Requires:       python3-gobject-Gdk

%description
Liferea is an abbreviation for Linux Feed Reader. It is a news
aggregator for online news feeds. It supports a number of different
feed formats including RSS/RDF, CDF, Atom, OCS, and OPML. There are
many other news readers available, but these others are not available
for Linux or require many extra libraries to be installed. Liferea
tries to fill this gap by creating a fast, easy-to-use, easy-to-install
news aggregator for GTK and GNOME.

%lang_package

%prep
%autosetup -p1

%build
%if 0%{?suse_version} >= 01550 || 0%{?sle_version} >= 150200
export WEBKIT_DISABLE_COMPOSITING_MODE=1
%endif
%configure --disable-static
%make_build

%install
%make_install
%suse_update_desktop_file net.sourceforge.liferea X-SuSE-RSS-News
%find_lang %{name} %{?no_lang_C}
rm doc/Makefile*
rm doc/html/Makefile*

%fdupes %{buildroot}

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.xml

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post
%glib2_gsettings_schema_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%glib2_gsettings_schema_postun
%endif

%files
%license COPYING
%doc AUTHORS ChangeLog
%{_bindir}/liferea
%{_bindir}/liferea-add-feed
%{_datadir}/applications/net.sourceforge.liferea.desktop
%{_datadir}/dbus-1/services/net.sourceforge.liferea.service
%{_datadir}/%{name}/
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/net.sourceforge.liferea.appdata.xml
%{_datadir}/GConf/gsettings/liferea.convert
%{_datadir}/glib-2.0/schemas/net.sf.liferea.gschema.xml
%{_datadir}/icons/hicolor/*/*/*.*
%{_libdir}/%{name}/
%doc %{_mandir}{,/*}/man1/liferea.1*

# We can't really move the localized manpages to the lang package, since they'd
# create a conflict between the lang subpackage and bundles
%files lang -f %{name}.lang

%changelog
* Fri Sep 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.14.6:
  + Fixes #1272: crash when moving feed to empty folder
  + Fixes #1198: FreshRSS logging in correctly but can't get posts
  + Fixes #1248: Can’t maximize for reading feeds
- Add be8ef494.patch: add `#include <libxml/tree.h>` for
  `xmlNodePtr` type.
- Rebase liferea-opensuse-feeds.patch to apply with -p1.
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Prepare for RPM 4.20: use autosetup.
* Thu Apr 13 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.14.5:
  * Drop tray icon plugin from list of per-default activated plugins
  * Fix corrupted double-linked list (gh#lwindolf/liferea#1127)
  * Fix assertion when deleting feeds too quickly
    (gh#lwindolf/liferea#1229)
  * Fix format and cast errors (gh#lwindolf/liferea#1223)
* Sat Apr  1 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.14.4:
  * Fix endless recursion in 1.14.3
    (gh#lwindolf/liferea#1217, gh#lwindolf/liferea#1224)
  * Additional fix for crash in conf_get_bool_value_from_schema
    (gh#lwindolf/liferea#1214)
  * Fixes a g_object_unref warning on shutdown
  * Drops a debug output in the plugin installer
* Wed Mar 29 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.14.3:
  * fix crash when refreshing feeds (gh#lwindolf/liferea#1212)
  * fix memory leak when reloading CSS
  * fix crash in conf_get_bool_value_from_schema
    (gh#lwindolf/liferea#1214)
  * fix failing build in launchpad PPA due to auto_test
    permission issue (gh#lwindolf/liferea#1215)
* Mon Mar 13 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.14.1:
  + Fix CVE-2023-1350 - Remote code execution on feed enrichment
    (boo#1209190).
* Fri Jan 20 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use the properly boostrapped release tarball from upstream.
- Drop libtool BuildRequires and no longer run autogen.sh.
* Sun Jan 15 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.14.0
  + New 'Reader mode' preference that allows stripping all web
    content
  + Implement support for Webkits Intelligent Tracking Protection
  + New progress bar when loading websites
  + Youtube videos from media:video can be embedded now with a
    click on the video preview picture.
  + Changes to UserAgent handling: same UA is now used for both
    feed fetching and internal browsing.
  + New view mode 'Automatic' which switches between 'Normal' and
    'Wide' mode based on the window proportions.
  + Liferea now supports the new GTK dark theme logic, where in
    the GTK/GNOME preferences you define wether you "prefer" dark
    mode or light mode
  + Favicon discovery improvements: now detects all types of Apple
    Touch Icons, MS Tile Images and Safari Mask Icons
  + Increase size of stored favicons to 128x128px to improve icon
    quality in 3-pane wide view.
  + Make several plugins support gettext
  + Allow mutiple feed in same libnotify notification
  + Redesign of the update message in the status bar. It now shows
    a update counter of the feeds being in update.
  + You can now export a feed to XML file
  + Added an option to show news bins in reduced feed list
  + Added menu option to send item per mail
  + Default to https:// instead of http:// when user doesn't
    provide protocol on subscribing feed
  + Implement support for subscribing to LD+Json metadata listings
    e.g. concert or theater event listings
  + Implement support for subscribing to HTML5 websites
  + Support for media:description field of Youtube feeds
  + Improve HTML5 extraction: extract main tag if it exists and
    no article was found.
  + Execute feed pipe/filter commands asynchronously
  + Better explanation of feed update errors.
  + Added generic Google Reader API support (allows using FeedHQ,
    FreshRSS, Miniflux...)
  + Now allow converting TinyTinyRSS subscriptions to
    local subscriptions
  + New search folder rule to match podcasts
  + New search folder rule to match headline authors
  + New search folder rule to match subscription source
  + New search folder rule to match parent folder name
  + New search folder property that allows hiding read items
  + Now search folders are automatically rebuild when rules are
    changed
  + Added new plugin 'add-bookmark-site' that allows to configure
    a custom bookmarking site.
  + Added new plugin 'getfocus' that adds transparency on the feed
    list when it is not focussed.
  + Trayicon plugin has now a configuration option to change the
    behaviour when closing Liferea.
  + Trayicon plugin has now an option to disable minimizing to tray
  + New hot key Ctrl-D for 'Open in External Browser'
  + New hot key F10 for headerbar plugin to allow triggering the
    hamburger menu
  + New hot key Ctrl-0 to reset zoom
  + New hot key Ctrl-O to open enclosures
  + Fix hidden panes, Liferea will never allow the panes to be
    smaller than 5%% in height or width
  + Wait for network to be fully available before updating
  + 2-pane mode was removed
  + Dropped CDF channel support
  + Dropped Atom 0.2/0.3 (aka Pie) support
  + Dropped blogChannel namespace support
  + Dropped photo namespace support
- Add libtool BuildRequires and run autogen.sh: the tarball is an
  unbootstrapped git archive.
* Thu Jan 13 2022 Michael Gorse <mgorse@suse.com>
- Require python3-cairo; needed for tray icon (boo#1193579).
* Tue Jul 13 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Fix missing python3-gobject-Gdk runtime dependency (boo#1187936)
* Sat May  8 2021 Fusion Future <qydwhotmail@gmail.com>
- Update to version 1.13.6:
  * Change reader mode toggle from item view icon to toggle entry in item view context menu.
  * #343: UX redesign of the update message in the status bar. Now shows a update counter of the feeds being in update.
  * #964: Added pane position fix plugin providing a workaround for pane position issues when using the headerbar
  * #983: Use GtkFileChooserNative to allow selecting local files when run in sandbox.
  * Fixes #780: Improve date formatting when in locale en_GB
  * Fixes #944: Broken RTL text direction in feed content view
  * Fixes #949: Regression in notification plugin that caused it to show non-new items
  * Fixes #963: Checking for git command in plugin installer -> warn user
  * Fixes #973: Broken CSS in Webkit2Gtk >= 2.32
  * Updated Albanian translation
  * Updated French translation
  * Updated Italian translation
  * Updated German translation
  * #907: Add new search folder property that allows hiding read items
  * Now always shows the unread count of a search folder (instead of the item count) in the feed list
  * Now search folders are automatically rebuild when rules are changed
  * Adds a new simple focus plugin that adds transparency on the feed list when it is not focussed.
  * Add F10 hotkey to headerbar plugin to allow triggering the hamburger menu
  * Update Flatpak AppData with release dates
  * Make several plugins support gettext
  * Fixes #192: wrong button order of media player in RTL locales
  * Fixes #343: Usability of update infos in status bar. Now a total count is displayed on mass-updates and a per-feed info on single feed updates
  * Fixes #809: Usability of feed fetching errors.
  * Updated Polish translation
  * Updated German translation
  * Prevent endless loop on favicon discovery
  * #903: Prevent endless loop in feed autodiscovery
  * #912: Allow mutiple feed in same libnotify notification
  * Further favicon discovery improvements: now detects all types of Apple Touch Icons, MS Tile Images and Safari Mask Icons Fixes #440
  * Add reader mode toggle in the item view
  * #876 Add reader mode preference
  * Implement support for subscribing to LD+Json metadata listings e.g. concert or theater event listings
  * Provide the default icon for feeds with no favicon as SVG for nicer rendering in wide view. Drop some unused icons. Replace tray icon with scalable version.
  * Fixes CRITICAL on trayicon plugin init
  * Fixes #884: Content of wrong feed is shown
  * Fixes #900: Flatpak needs icon named after appid
  * Fixes #908, #332: Search folder are not case-insensitive as documented
  * Fixes #899: Truncated articles (on 'Extrat full content')
  * #902: Updated Polish translation
  * #893: Update of bookmarking sites
  * #888: Changes required for Flathub
  * #882: Implement support for Webkits Intelligent Tracking Protection
  * #875: Add <Ctrl>-0 hotkey to reset zoom
  * #874: Add debug printing of SAX parser errors
  * #846: Remove deprecated usage of gdk_screen_*
  * #844: Update metainfo path (appdata target directory)
  * #776: CSS color update on theme change without restart
  * Fixes #883: Feed with comments: last comment replaces all content
  * Fixes #866: Bad encoding in doc/html/reference_de.html
  * Fixes #865: Fixes view mode switch
  * Fixes #841: Now shows progress bar when loading websites
  * Fixes #828: Crashing with segfault after opening feed articles
  * Fixes XLST exception on mediarss feeds with description
  * Drop blogChannel namespace support
  * Support multi-feed discovery
  * Default to https:// instead of http:// when user doesn't provide protocol on subscribing feed
  * Drop CDF channel legacy support
  * Drop Atom 0.2/0.3 (aka Pie) legacy support
  * #893: Added Persion default feed list
  * #890: Update of Indionesian translation
  * #890: Update of French translation
  * #846, #864, #735: Fix main menu/toolbar not being translated
  * #854: Adding new search folder options to match subscription source ULR and parent folder name.
  * #851: Add accessibility check to code tests
  * #851: Fix accessibility annotations for several combo boxes.
  * #850: Fix embedded youtube video bug.
  * #765: Embed YouTube videos from MediaRSS feeds
  * #749: Add Readability.js library (Apache 2.0 licensed) and auto-apply Readability.js to all headlines
  * Drop unused glade/google_source.ui
  * Drop support of combined view mode, this is necessary to add rich content support which relies on DOM transformation and Readability.js
  * Drop ns_photo support, as it is rarely used and allows us to get rid of XSLT extra handling
  * #747: Font improvements
  * #250 Update some dialog labels
  * #803: Fix legacy links to mailing list and IRC in documentation.
  * Updated German translation
  * #861: Updated Spanish translation
  * Fixes #840: OPML source subfolders not working
  * #837: Removing GTimeVal references
  * #827: Respect global update refresh interval for TheOldReader
  * #826: Fix save/restore position issues with tray icon
  * #822: Improve performance of item list loading
  * Fixes #821: Skip current item when finding next unread item
  * #815: Add support for subscribing to HTML5 websites without RSS/Atom feeds by extracting article titles,links and descriptions
  * #816: Increase size of stored favicons to 128x128px to improve icon quality in 3-pane wide view. Also add favicon URL discovery tests.
  * Fixes #821: Skip current selected unread item on 'next unread item'
  * #800: Expose remove-item action for plugins
  * Fixes #799: plugins/headerbar.py translations not active
  * Fixes #783: Update IS_STATE when update item in itemlistview
  * #752: Trayicon plugin has now a configuration option to change the behaviour when closing Liferea.
  * Fixes #693: Add trayicon plugin option to disable minimizing to tray
  * #764: Add MediaRSS support (e.g. Youtube feeds) to display descriptions and thumbnails
  * #773: Add WebKit Inspector menu option to HTML view when run with --debug-html (by sillyslux)
  * #714: Replaces deprecated gtk_menu_popup
  * #705: New hotkey Ctrl-O to open enclosures
  * #680: Add xdg-email command to item list popup menu
  * Drop unused glade/google_source.ui
  * #699: Refactoring of duplicate check handlingg
  * #746: Fix accessibility fatals reported by gla11y
  * Fixes #730: "Update all subscriptions at startup" overrides "Don't update this feed automatically"
  * Fixes #639: Right clicking on article no longer selects it
  * #737: Update of Italian translation
  * #745: URL fix for French example feeds
  * Update inline docs on headline view modes
* Mon Dec 28 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.12.9:
  * Fix embedded youtube video bug
  * Fix translations not applied to application menu bar and tool bar
* Fri Jun 12 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.12.8:
  * Fixes #734: crash when selecting empty nodes
  * Fixes #727: Out-dated documentation on Firefox live bookmarks
  * Fixes headline large images/videos or images with margins
    causing horizontal scrolling in headline view
  * Fixes #840: OPML source subfolders not working
  * Update of French translation
* Thu May 14 2020 Max Lin <mlin@suse.com>
- Export WEBKIT_DISABLE_COMPOSITING_MODE=1 on Leap 15.2 build
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Jan 13 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Add export WEBKIT_DISABLE_COMPOSITING_MODE=1 as workaround for
  Factory build failure
  (https://github.com/lwindolf/liferea/issues/767)
* Thu Sep 12 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.12.6:
  * #658: Add confirmation dialog when adding duplicate subscription
  * Fixes #689: When resuming from sleep feeds were being fetched
    before Wifi came up
  * Fixes #685: Headerbar plugin "Mark All Read" button is not
    feed-specific
  * Fixes #549: Scrollbars not always present in the headline area
  * Fixes #543: Next update overrides HTML5 enrichment
  * Fixes overly wide label in enclosure preferences dialog
  * Dropped unencrypted warning from auth dialog (not true anymore)
  * #688: Adding translatable tooltips for the headerbar plugin
  * #665: Webkit browser now supplies 'Liferea' component in
    user agent
  * #664: Added "Mark All As Read" button to headerbar plugin
  * #620: Added flatpak JSON
  * #579: Added item list column drag and drop reordering
  * #436, #662: Move from GnomeKeyring to libsecret
  * Fixes #663: Correct instapaper sharing link
  * Fixes #661: Update sharing links
  * Fixes #271: Consistent over usage of CPU (trigger by
    "Next Unread" loop)
  * #472, #632: Dropping Inoreader support (API broke)
  * Fixes #660: Added installable plugin to change accels
  * Fixes #654: Segfault on date out of range
  * Fixes #651: Fixes Free Music Archive link in default OPMLs
  * Fixes #649: Switch from persistent to session-only cookies
  * Fixes #645, #646: unread count of vfolder
  * Fixes #637: Extra keywords in .desktop file
    (syndication; rss; atom)
  * Fixes #557: Updating counters for remote sources
  * Updated cookie usage hint in FAQ
  * #634: Added setting for custom download commands
  * #614: GTK Headerbar support via plugin
  * #608: Refactoring UI code to switch to GAction and GtkBuilder
  * Note: this implies not having icons in the main menu anymore
  * which were still there for all non-GNOME users (see #626).
  * #589: Item list view column order rework as a preparation
    for possible real column drag&drop. Introduces a new
    DConf setting for the column order.
  * Fixes #280: Mark read toolbar button always disabled for
    search folders
  * Fixes #591: Please add a safety question when
    "marking all read"
  * Fixes #625: Avoid exception in trayicon.py
  * Fixes #627: GnomeKeyring plugin fails to activate when
    keyring doesn't exist
  * Fixes #630: Fix feed list selection after DnD
  * Fixes #633: Big Memory leak in date code
  * Adding a plugin installer plugin that allows discovering
    and automatically installing 3rd party plugins
  * #585: Drop language from user agent to increase privacy
  * #583: Add transmission-gtk and aria2 as download tool options
  * #495: New command line option --disable-plugins (-p) to start
    with all plugins disabled.
  * Fixes #610: Liferea not showing up in GNOME Software
  * Fixes #604: Correctly print error message when failing to
    unlock GNOME keyring
  * Fixes #602: CSS style for GTK link colors not used
  * Fixes #581: Redirect location updates and adds HTTP 308
    (RFC 7538) support
  * Fixes #578: Unable to set unread items in bold
  * #584: Fixes broken OPML feed list entries
  * #577: Fixes newsbin doc typo
  * #584: Added Norwegian feed list
  * Translation updates
- rebase liferea-openSUSE-feeds.patch
- fixes boo#1150009
* Thu Dec 28 2017 zaitor@opensuse.org
- Update to version 1.12.1:
  + Fix Lintian spelling errors.
  + Appstream data has new format.
  + Fix doesn't remember some sort orders.
  + Fix assertions/crashes on changing view layouts.
  + Workaround to avoid GtkPaned shrinking.
  + Updated translations.
- Changes from version 1.12.0:
  + Fixes unhiding from tray icon when activated via GApplication.
  + Reorder columns in 'Normal' email-like view to have the date
    column always at the end.
  + Add plugin to make unread feeds titles bold.
  + Workaround Liferea deanonymize Tor.
  + Resize both panes in normal and wide view.
  + Toggle_visibility() does not make a minimized window visible
    again.
  + Segfault when switching feed in combined view.
  + Handling of relative URLs in Atom parser.
  + Added 'View Image' context menu option in HTML view.
  + Dropped del.icio.us from social bookmarking options as it is a
    read-only service now.
  + Redesign of the wide view mode: larger titles with small text
    teasers.
  + Added optional AMP/HTML5 content enrichment feature.
  + Updated translations.
- Conditionalize handling of desktop_database_post(un),
  icon_theme_cache_post(un) and glib2_gsettings_schema_postun in
  post(un) to only apply for old versions of openSUSE.
- Clean up spec, drop obsolete clean section.
* Wed Jun 28 2017 dimstar@opensuse.org
- Change license to 'GPL-2.0' in place of 'GPL-2.0+':
  src/debug.[c|h]) does not specify 'or higher'.
* Wed Jun 21 2017 zaitor@opensuse.org
- Update to version 1.12~rc3:
  + Fix GtkDoc warnings.
  + Filter commands are not asynchronous.
  + Missing space above internal browser address bar.
  + All "Unread" search folder items marked read at once.
  + Liferea does not always use theme icons when it is launched on
    system startup.
  + Updated translations.
- Changes from version 1.12~rc2:
  + Change all g_warnings() to g_print() for remote source to avoid
    "crashing" on errors.
  + Reorganized all UI definitions in separate files to simplify
    GtkBuilder handling.
  + Add GeoRSS info and map link in item header.
  + Replacing deprecated elements in preferences.
  + Create LifereaApplication type.
  + Partial RFC3229+feed support for bandwidth savings.
  + gtk_tree_store_get_path: assertion
    'iter->stamp == priv->stamp'.
  + Leftover OSM XSLT in item view.
  + Internal browser shows files system on go-back.
  + Updated translations.
- Changes from version 1.12~rc1:
  + Switch to webkit2gtk3.
  + Support for Do-Not-Track.
  + Improved trayicon plugin.
  + Support for Reedah and InoReader.
  + Support for categories in TheOldReader.
  + Simplified handling of external browsers.
- Replace pkgconfig(webkitgtk-3.0) with pkgconfig(webkit2gtk-4.0)
  BuildRequires following upstreams port.
* Wed Mar  8 2017 zaitor@opensuse.org
- Update to version 1.11.7:
  + Add support for media:group.
  + Fix issues with media:content.
  + Bad .desktop categories definition.
  + Fix rules no visible in searchdialog.
  + "Download" tab in Tools/Preferences.
  + Segfault when sorting feeds in folder.
  + Updated manpage.
  + Updated translations.
* Mon May  2 2016 zaitor@opensuse.org
- Update to version 1.10.19:
  + Fixes gh#lwindolf/liferea#317: Compilation problems in 1.10.18
    release.
  + Fixes gh#lwindolf/liferea#73: Problem with updating favicons.
* Sat Feb 20 2016 zaitor@opensuse.org
- Update to version 1.10.18:
  + Fix gh#lwindolf/liferea#287: media:content support broken.
  + Fix gh#lwindolf/liferea#279: Rules not visible in searchdialog.
  + Fix gh#lwindolf/liferea#83: Segfault when sorting feeds in
    folder.
  + Fix gh#lwindolf/liferea#302: Broken compilation with
  - -disable-notify.
- Changes from version 1.10.17:
  + Fix gh#lwindolf/liferea#194: Add source dialog visually broken.
  + Fix gh#lwindolf/liferea#195: Out-dated documentation on
    enclosure download.
  + Fix gh#lwindolf/liferea#223: Search folder dialog don't show
    rules.
  + Fix gh#lwindolf/liferea#227: Preference dialog fails to load
    with latest GtkBuilder.
  + Fix gh#lwindolf/liferea#234: Segmentation fault upon attempting
    to add an OPML.
  + Fix compilation error when there is no libnotify.
  + Added debugging for gh#lwindolf/liferea#258: Dialog loading
    issues.
- Changes from version 1.10.16:
  + Added "Do Not Track" support (enabled per default).
  + Added x-scheme-handler/feed to desktop file.
  + Add image icons to plugins.
  + Enable tests for parsing RFC822 dates with 2 digit year.
  + Fix gh#lwindolf/liferea#78: Shaky text in feed list.
  + Fix gh#lwindolf/liferea#195: Out-dated documentation on enclose
    download.
  + Fix gh#lwindolf/liferea#198: Traceback on popup notifications.
  + Fix gh#lwindolf/liferea#216: Untranslatable strings.
  + Fix gh#lwindolf/liferea#256: PyGIWarnings on loading plugins.
- Changes from version 1.10.15:
  + Implement full screen mode for videos.
  + Fix gh#lwindolf/liferea#32: Prevent erroneous "Mark all as
    read".
  + Improves gh#lwindolf/liferea#36, gh#lwindolf/liferea#113: UI
    lock up during refresh.
  + Fix gh#lwindolf/liferea#180: Removing item from (v)folder marks
    all read.
  + Fix gh#lwindolf/liferea#140, #158: Vertical pane placement is
    forgotten.
  + Fix gh#lwindolf/liferea#182: Missing config.h include in
    date.c.
* Sun Mar  1 2015 badshah400@gmail.com
- Update to version 1.10.14 (boo#916784):
  + Fix gh#lwindolf/liferea#154: Crashes while starting (on
    corrupt icon).
  + Fix gh#lwindolf/liferea#134: Broken default news feed.
  + Fix gh#lwindolf/liferea#122: Crashes at launch,
    "segmentation fault".
  + Fix some memory leaks.
  + Fix gh#lwindolf/liferea#145: Wrong method triggered on
    'Launch External'.
  + Fix gh#lwindolf/liferea#149: Fixes a random crash on startup.
- Changes from version 1.10.13:
  + Fix gh#lwindolf/liferea#112: Wrapping issue in folder display.
  + Fix gh#lwindolf/liferea#114: Avoid termination on UTF-8
    validation error.
  + Fix gh#lwindolf/liferea#132: Broken link in documentation.
* Tue Oct 28 2014 badshah400@gmail.com
- Update to version 1.10.12 (boo#906687):
  + Fix gh#lwindolf/liferea#86: Support HTTP content negotiation
  + Fix gh#lwindolf/liferea#98: Stop calling Atom person
    constructs w/ URI invalid
  + Fix gh#lwindolf/liferea#100: Problems with dark Adwaita theme
    in GTK 3.14
- Changes from versions 1.10.6 through 1.10.11:
  + See ChangeLog file
    (/usr/share/doc/packages/liferea/ChangeLog).
* Thu Jan 16 2014 zaitor@opensuse.org
- Update to version 1.10.5 (bnc#859043):
  + sf#1056, sf#1089, sf#1098: Honor preferences when opening
    links.
  + sf#1096: missing installation of liferea.convert file.
  + rh#947358: popup notification only for new items.
* Wed Jan 15 2014 zaitor@opensuse.org
- Update to version 1.10.4 (bnc#858588):
  + sf#1123: Mistakenly claims "TinyTinyRSS source is not
    self-updating".
  + sf#1119: Crash on font resize at startup.
  + sf#1117: Selecting last unread item in reduced feed list jumps
    to next feed.
  + Updated translations.
* Wed Oct 16 2013 firebird209@gmail.com
- Update to version 1.10.3:
  + Ask for credentials again if TinyTinyRSS login fails.
  + Ask for TinyTinyRSS credentials only 3 times.
  + Check whether TinyTinyRSS base URL is lost.
  + Added warning on TinyTinyRSS login when source is not
    self-updating.
  + "--debug-net --debug-verbose" now traces POST data.
  + Add GNOME AppData XML.
  + Updated the default feed lists.
  + Updated translations.
* Sat Sep  7 2013 dimstar@opensuse.org
- Update to version 1.10.2:
  + sf#222: Make media player seekable.
  + sf#1102: Spelling error in man page.
  + sf#1104: liferea.desktop missing keywords.
  + sf#1105: Start Minimized to Tray Does Not Work.
  + sf#1114: Crashes opening browser on item without link via
    popup.
  + Improved handling of broken Atom author information.
  + Removed dead Google Reader code to avoid doing requests to
    Google. Replaced with dummy source that even allows normal feed
    updates.
  + Added hint to FAQ on how to workaround broken Flash support.
  + Dumping feedlist.opml with indentation for readability.
- Changes from version 1.10.1a:
  + sf#1102: Liferea does not show a window.
- Changes from version 1.10.1:
  + sf#1059: Liferea crashes with system proxy enabled.
  + sf#1095: Theme color detection bug / white fonts.
  + sf#1097: Default feed refresh interval cannot be set to 0.
  + sf#1100: --debug-gui crashes with segmentation fault.
  + sf#1101: Outdated manpage.
  + sf#225: Make media player work with GStreamer 1.0.
  + sf#226: Add trailing semi-colon to MimeType so that the desktop.
  + sf#227: Remove letfover square bracket configure.ac.
  + sf#228: Add net.sf.liferea.gschema.xml to AC_CONFIG_FILES.
- Drop liferea-fix-invalid-desktop.patch: fixed upstream.
* Sun Jul 21 2013 zaitor@opensuse.org
- Add liferea-fix-invalid-desktop.patch, fixes invalid desktop
  file due to missing semicolon.
* Fri Jul 19 2013 dimstar@opensuse.org
- Update to version 1.10.0:
  + Added experimental sync support for TheOldReader.
  + Removed 'Update' link in comments display as it is pretty
    useless.
  + Removed 'No Comments' display as it is rather useless.
  + Prevent re-rendering item display on setting item flagged.
  + Changed unread number rendering to be right bound and
    non-ellipsized.
  + Fixes g_strstr_len assertions caused by search folder item
    matching.
  + Updated documentation to reflect Google Reader, TheOldReader
    changes.
  + Removed welcome text, restoring last feed/item selection
    instead.
  + autogen.sh now reports errors on missing autoconf or intltool.
  + Correctly check for gobject-introspection build dependency.
  + Fixes missing shading in 2-pane mode rendering.
  + Many bugfixes.
  + Updated translations.
- Add glib schema handling macro calls to post/postun.
- Remove all gconf schema handling scripts.
- No longer pass --disable-schemas-install to configure.
- Clean up conditionals in the .spec file addressing
  openSUSE <= 11.3.
- Update BuildRequires, following upstreams massive changes:
  + Removed: json-glib-devel, libsoup-devel, libunique1-devel,
    libwebkit-devel, libxslt-devel, sqlite-devel,
    pkgconfig(gconf-2.0), pkgconfig(gtk+-2.0), pkgconfig(ice),
    pkgconfig(sm).
  + Added: pkgconfig(gobject-introspection-1.0),
    pkgconfig(gsettings-desktop-schemas), pkgconfig(gtk+-3.0),
    pkgconfig(json-glib-1.0), pkgconfig(libpeas-1.0),
    pkgconfig(libpeas-gtk-1.0), pkgconfig(libsoup-2.4),
    pkgconfig(libxml-2.0), pkgconfig(libxslt), pkgconfig(pango),
    pkgconfig(sqlite3), pkgconfig(webkitgtk-3.0).
* Tue Jun 25 2013 dimstar@opensuse.org
- Update to version 1.8.15:
  + Added an option to convert Google Reader subscriptions to local
    feeds.
  + sf#1080: segfault opening attachment due to incorrect g_free().
  + sf#1075: GLib warnings of "string != NULL" assertion failure.
  + Fixes search folders including comment items.
* Thu May 23 2013 dimstar@opensuse.org
- Update to version 1.8.14:
  + sf#1069: broken rendering in tt-rss feeds.
* Sun May 12 2013 dimstar@opensuse.org
- Update to version 1.8.13:
  + Fixes missing item list update when browsing item URLs in
    Liferea.
  + Fixes format string issues in several translations.
  + Added Hebrew translation of reference manual page.
  + Added MimeType to .desktop file.
  + Fixes sf#1040: In feed entries, spaces are replaced with "+".
  + Fixes sf#1051: Issues in RTL GUI of Liferea.
  + Fixes sf#1038, sf#1074: Updates ttrss feeds over and over.
  + Updated the default feedlists.
  + Updated translations.
- Rebase liferea-opensuse-feeds.patch.
* Fri Jan  4 2013 dimstar@opensuse.org
- Update to version 1.8.12:
  + Some GPLv2 license headers were outdated (sf#1041).
  + tt-rss API changed (we now support only 1.6 API) (sf#1044)
  + Fixes XHTML errors caused by extra <body> tags from tt-rss
- Changes from version 1.8.11:
  + Added Google Plus to social bookmarking options.
  + x-www-browser preference not working (deb#668197)
  + Incorrect notifications for Google Reader (sf#1037)
  + Removed all feedvalidator.org references from FAQ and XSLT as
    it was reported to host malware (sf#1048).
  + Updated translations.
* Wed Oct 31 2012 dimstar@opensuse.org
- Update to version 1.8.10:
  + Fix crash in google_source_remove_node (sf#3572660).
  + Prevents adding folders/search folders/newsbins to Google
    Reader.
  + Prevents sorting subscriptions in Google Reader
  + Fixes items not removed from search folder count when feed is
    removed.
  + Fixes search folder rebuilding (do not include comment items).
  + Fixes SELECT offset handling when rebuilding search folders.
* Wed Oct 10 2012 dimstar@opensuse.org
- Update to version 1.8.9:
  + Added Instapaper.com to social bookmarking sites (sf#3564393)
  + Fix crash on network online status changes (sf#3567715)
  + Fixes preferences dialog not showing up a second time.
  + Fixes reloading item when browsing inside the item view.
* Fri Sep 14 2012 vuntz@opensuse.org
- Update to version 1.8.8:
  + Fixes crash on empty links in auto-load-link mode (sf#3557513).
  + Ensure node ids are in DB node relation on startup.
  + Fixes search folder counter update on feed removal.
  + Include AM_PROG_AR in configure.ac to work with automake 1.12.
* Wed Aug 29 2012 dimstar@opensuse.org
- Fix liferea-opensuse-feeds.patch (bnc#777737): openSUSE Feed
  URLs with duplicate http://.
* Tue Jul 31 2012 dimstar@opensuse.org
- Update to version 1.8.7:
  + Crash on empty search folders within folders (trac#10)
  + Auto-load-link doesn't work with feeds with comments (trac#19)
  + Crash when dragging Google Reader feeds outside Google Reader
    (sf#2855990, bnc#772538)
  + Don't ask for Google Reader authentication more than three
    times with auto-update to avoid annoying the user
  + Dropping SIGSEGV signal handler to allow distro crash report
    tools to work
  + Updated translations.
* Sun Jun 17 2012 badshah400@gmail.com
- Update to version 1.8.6:
  + Fixes ever growing temporary DB files
  + Fixes visibility of enclosure list view for Ubuntu.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.8.5:
  + Reimplemented feed title matching rule for search folders.
  + Missing include when compiling with libindicate (sf#3515880).
  + Fixes search folders being invisible in reduced mode.
- Drop liferea-missing-include.patch: fixed upstream.
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 1.8.4:
  + Improve DB item counting statements.
  + Change OpenStreetMap rendering from osmarender to mapnik.
  + Reimplemented search folder rule for item with enclosures.
  + Reimplemented search folder rule for item categories.
  + sf#3480238: crashes when double clicking find
  + deb#660602: Item pane may be reset during feed update
- Add liferea-missing-include.patch: add missing include to fix
  build.
* Sat Mar 24 2012 vuntz@opensuse.org
- Update to version 1.8.3:
  + Increasing sqlite3 dependency to 3.7+ for WAL journaling.
  + Removed sqliteasync code in favour of WAL journaling. This
    significantly improves performance for ext4.
  + Added indices for parent_item_id and parent_node_id to avoid
    slow item removal.
* Wed Mar 21 2012 vuntz@opensuse.org
- Update to version 1.8.2:
  + Prevent node info update for anything besides folders.
  + Do not update DB node and subscription info on startup for
    performance reasons.
  + Perform VACCUM only when page fragmentation ratio < 10%%.
  + Removed tooltip on the "Next Unread Item" button to avoid
    having it flashing each time it is clicked when skimming
    through items.
- Drop liferea-avahi.patch: there is nothing useful left in there
  after a rebase, as it would just remove dead code.
- Remove libtool BuildRequires and call to autoreconf, that were
  only needed for above patch.
* Thu Mar 15 2012 vuntz@opensuse.org
- Update to version 1.8.1b:
  + Fixes Makefile problem.
- Rebase liferea-avahi.patch.
* Sun Mar  4 2012 dimstar@opensuse.org
- Update to version 1.8.1:
  + Fixes proxy preference not affecting the HTML widget.
  + Feeds fail to update properly when entries ordered "wrong"
    (sf#3363481)
  + Fixes writing subscriptions into DB when importing from OPML
  + Revert ISO 8601 parsing using Glib due to deb#653196
    (sf#3465106)
  + Can't drag and drop feed to empty folder (sf#3484742)
- Add liferea-avahi.patch: remove all remainders of avahi after it
  got stripped upstream.
- Note that libtool and call to autoreconf were still there, while
  there was no patch; they're now needed for above patch.
- Clean spec file using spec-cleaner. This resulted in some
  BuildRequires moving to pkgconfig() style:
  + Old: gconf2-devel, glib2-devel, gtk2-devel, libnotify-devel.
  + New: gconf-2.0, glib-2.0, gtk+-2.0, libnotify.
* Mon Feb 20 2012 vuntz@opensuse.org
- Add explicit pkgconfig(ice) and pkgconfig(sm) BuildRequires, to
  avoid issues after the big xorg-x11 packaging change.
* Thu Jan  5 2012 vuntz@opensuse.org
- Remove NetworkManager-devel, dbus-1-glib-devel, libglade2-devel,
  lua-devel BuildRequires: not needed anymore.
- Add explicit glib2-devel and libsoup-devel BuildRequires: they
  were implicitly brought in before.
* Sun Dec 11 2011 cthiel@suse.com
- Update to version 1.8.0:
  + Many performance improvements.
  + Better Google Reader support.
  + Better TinyTinyRss 1.5+ support.
  + New inline browser link+image actions.
  + Allow sorting subscriptions.
  + Allow reordering of browser tabs.
  + Many other changes, see ChangeLog for details.
- Add json-glib-devel and libunique1-devel BuildRequires: new
  dependencies upstream.
- Drop liferea-libnotify07.patch: fixed upstream.
- Rebase liferea-opensuse-feeds.patch.
* Sat Dec  3 2011 zaitor@opensuse.org
- Update liferea-opensuse-feeds.patch: replace dead url
  planetsuse.org with current planet.opensuse.org.
* Tue Nov 29 2011 dimstar@opensuse.org
- Update to version 1.6.7:
  + DB contains comments of deleted feed entries [sf#3046762]
  + Deleting a feed also removes items copied to news bins
    [sf#3441643]
  + Updated translations.
- Drop liferea_dbus.xml: It's back in the tarball.
* Thu Nov 24 2011 dimstar@opensuse.org
- Update to version 1.6.6b:
  + Fixes build error.
- Rebase liferea-libnotify07.patch.
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Jun 22 2011 dimstar@opensuse.org
- Update to version 1.6.6:
  + Removed the obsolete Bloglines support.
  + Removed bookmarking support for the dead Backflip.
  + Fixes second search not clearing item list.
  + Fixes accidental drag&drop in HTML view.
  + sf#3019444 and sf#2978831: incorrect handling of HTTP 301
  + sf#3103875: Opening URLs with UTF-8 characters
  + deb#600638: Wrong number of unread items in mouse over tray
    icon with zh_TW locale.
  + liferea.glade: Mark 2 messages as translatable that were
    wrongly not marked.
  + Fix build with stricter linkers.
  + Updated translations.
- Drop patches:
  + libnotify-0.7-api.patch: the 1.6.x tree got changed to not
    support libnotify > 0.5. Additionally, it's overcomplex. In
    order to support libnotify 0.7, we have a new patch.
  + liferea-1.6.5-nm09.patch: fixed upstream.
- Add liferea-libnotify07.patch: upstream wanted to limit usage of
  libnotify to maximum 0.5.x in liferea 1.6.x tree, which is
  something we don't want to do.
- Add liferea_dbus.xml as SOURCE1: the file is missing in the
  tarball.
* Mon Apr 11 2011 fcrozat@novell.com
- Add libnotify-0.7-api.patch: fix build with libnotify 0.7.x (git)
- Add liferea-1.6.5-nm09.patch: fix compatibility with NM 0.9 (git)
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec  7 2010 vuntz@opensuse.org
- Tag localized man pages with the right language. We should
  eventually move them to the lang subpackage, but at the moment,
  they would create a file conflict between bundles and the lang
  subpackage.
* Wed Sep 29 2010 vuntz@opensuse.org
- Update to version 1.6.5:
  + sf#3067801: crash in enclosure handling
  + deb#593415: Seems to misidentify MIME type of some podcast
    enclosures
  + sf#3012833: Ctrl-A in url bar or a text box should select all
    text
  + Updated translations.
* Wed Aug  4 2010 dimstar@opensuse.org
- Update to version 1.6.4:
  + sf#2965158: Enclosures URLs with spaces do not work.
  + Added identi.ca bookmarking support.
  + sf#2994622: Atom author URIs not markup escaped.
  + sf#2901447: comma in link prevents launching browser
  + Removed the unused attention profile code.
  + sf#3019939, deb#586926: Broken Google Reader authentication.
  + Updated translations.
* Mon Jun 14 2010 vuntz@opensuse.org
- Do not replace categories in .desktop file, just append the one
  we want. This makes liferea appear in the right place in our
  menus.
* Tue Feb 23 2010 vuntz@opensuse.org
- Update to version 1.6.3:
  + sf#2938905: never ending password prompt for Google Reader.
  + Updated translations.
- Rebase liferea-opensuse-feeds.patch.
* Fri Jan 22 2010 vuntz@opensuse.org
- Update to version 1.6.2:
  + Fixes sf#2907915: gdk_draw_pixbuf width/height ordering
  + Fixes deb#560201: Liferea doesn't remember font size
  + Fixes sf#2872001: Fix compilation against NetworkManager 0.8
  + Fixes an RSS 1.1 parsing bug that caused items not to be parsed
    at all
  + Fixes sf#2883971: proxy authentication doesn't work
  + Updated translations.
- Add call to autoreconf to fix an issue with libtool version
  mismatch.
* Fri Nov 27 2009 dimstar@opensuse.org
- Update to version 1.6.1:
  + Re-add grayflag.png since it is actually used.
  + Document that WebKitGTK+ 1.1.10 built with gcc 4.4 crashes
    often
  + Fixes sf#2831007: Opening enclosures by URL fails
    intermitantly
  + Fixes sf#2897668: crash when adding Bloglines subscriptions.
  + Fixes sf#2823526: Increase the width of the left column
    in the Script Manager.
  + Fixes deb#539857: Hide link cosmos for items that don't have
    a valid url, instead of displaying it and crashing when
    clicked.
  + Fixes sf#2861203: Crash when creating new search folder.
  + Added a timeout for downloads. (Arnold Noronha)
  + Patch sf#2894307: Fixes <tab> key cycling in items list.
* Mon Aug  3 2009 vuntz@novell.com
- Update to version 1.6.0:
  + Revert item_set_description() to the 1.4 code since the HTML
    detection created too many false negatives.
  + Updated translations.
- Changes from version 1.6.0-rc7:
  + Open the "Decrease/Increase Text Size" menu instead of the
    normal link menu on JavaScript links.
  + Fixes sf#2787817, sf#2814022: Work around several eggtrayicon
    crashes.
  + Fix target="_blank" links not opening in tabs.
  + Fixes a crash on some newsbin items without parents.
  + Open new windows opened by Javascript in a new tab.
  + Fixes crash when removing Google Reader node when update of one
    of it's subscriptions is in progress.
  + Fixes sf#2789255: Crash when quitting during download.
  + Reduce memory usage by only using a WebKitWebSettings for all
    the htmlviews.
  + Fixes sf#2823359: Subscription -> New Source crashes
  + Require WebKitGtk+ >= 1.1.10 to avoid problems with older
    versions.
  + Fixes sf#2815397: Don't scale images when scaling the text.
  + Work around a format misdetection in item_set_description().
  + Infinite loop on 404 errors.
  + Updated translations.
- Changes from version 1.6.0-rc6:
  + Updated the example feeds.
  + Updated the social bookmarking sites.
  + Added Twitter Search support.
  + Added Identi.ca Search support.
  + Support non-RFC822 alphabetic timezones.
  + Fix favicon downloads when the feed contains a link with
    leading or trailing whitespace.
  + Fixes comment feed hiding when comment feed is disabled.
  + Don't use the deprecated soup_message_headers_get() function.
  + More consistent tab label widths.
  + Avoid having loading of other tabs cancelled when opening a new
    tab.
  + Updated translations.
- Respin liferea-opensuse-feeds.patch, thanks to Claes Backstrom.
* Mon Jun 15 2009 vuntz@novell.com
- Update to 1.6.0-rc5. This is a new branch with major changes:
  + Use WebKit instead of Gecko/GtkHTML2 to render HTML.
  + Significant improvements in performance while updating an item
    in the DB.
  + Google Reader support.
  + New advanced search dialog functionality.
  + Add GeoRSS support by presenting the location using a
    OpenStreetMap or Google Maps embed.
  + Add namespace support for:
  - Yahoo Media
  - iTunes
  - trackback
  + Flash is now stripped from feed content per default.
  + New icons.
  + Many bug fixes.
- Add libwebkit-devel BuildRequires and remove mozilla-xulrunner
  BuildRequires and Requires.
- Remove gnutls-devel BuildRequires.
- Do not pass non-existing --disable-gtkhtml2 and
  - -with-gecko=libxul options to configure.
- Do not add categories to desktop file that are already there.
* Wed May  6 2009 vuntz@novell.com
- Build against mozilla-xulrunner191 on openSUSE > 11.1.
* Wed Apr 15 2009 vuntz@novell.com
- Update to version 1.4.28:
  + Adds a possible fix for the 100%% CPU issues by settings
    places.frecency.updateIdleTime to 0.
- Don't package empty NEWS file.
* Sat Mar 14 2009 vuntz@novell.com
- Update to version 1.4.27:
  + sf#2537587: Changes XulRunner detection to work on some odd
    Debian setups
  + sf#2579914: Mozilla plugin doesn't compile, by not calling
    gtk_moz_embed_set_comp_path() anymore.
  + sf#2685494: Merge example feeds from trunk.
  + Updated translations.
- Respin liferea-opensuse-feeds.patch, and remove the Novell Forge
  feed -- it's not that active.
* Sun Feb 22 2009 vuntz@novell.com
- Update to version 1.4.26:
  + sf#2570424: Fix build with --disable-gecko
* Sat Feb 21 2009 mboman@suse.de
- Update to version 1.4.25:
  + sf#2570424: Possible recursive C++ build dependency problem
  + Translation updates
- Remove liferea-1.4.18-xulrunner-1.9.patch since it was not used
- Remove %%if checks for version <= 10.2
- Remove AutoReqProv since it's default
- Remove CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" and
  CXXFLAGS="$CFLAGS"
- Remove dbus-1-devel, hicolor-icon-theme and libstdc++-devel from
  BuildRequires
- Add dbus-1-glib-devel to BuildRequires
* Mon Feb  2 2009 cthiel@suse.de
- update to version 1.4.24
  * Flash is now stripped from feed content per default.
  * Added preference option to allow Flash in feed content.
  * Fixes cross compilation issue with configure.ac using
    AC_CANONICAL_TARGET instead of AC_CANONICAL_HOST
  * Fixes local CSS/image loading problems with Webkit.
  * Allow compilation against recent Webkit 1.1.0 (r39804)
    which changed the ABI
  * New Greek translation
  * New Albanian translation
  * Update of Russion translation
- changes in version 1.4.23
  * Fixes unsubstituted variable in start script.
  * Fixes Debian #494741: Crashes on exit after closing
    update monitor dialog with ESC.
* Fri Nov 28 2008 cthiel@suse.de
- update to version 1.4.22d
  * Fixes a typo in XulRunner initialization #ifdef
  * Fixes a typo in configure.ac
  * Fixes SF #2266119: configure error if gecko disabled.
  * Fixes a XulRunner build issue with new gecko.m4 macro.
- removed liferea-1.4.22b.patch, included upstream
* Mon Nov 10 2008 cthiel@suse.de
- adding liferea-1.4.22b.patch by Wolfgang Rosenauer, to really fix the crash
  (bnc#440800)
* Mon Nov 10 2008 cthiel@suse.de
- update to version 1.4.22b
  * Fixes a DB migration issue that might occur when upgrading from schema
    version < 5 to 7.
  * New M4 macro for Gecko detection derived from Yelp.  This should improve
    compilation against XulRunner 1.9 on Debian.
  * Removes gray colouring of updated item titles.  This often confused
    users to believe the item state was unread.
  * Fixes for French translation
- fixes liferea crash (bnc#440800)
* Wed Oct  1 2008 mboman@suse.de
- Update to version 1.4.20:
  + Fixes SF #2042420: "Toggle Read Status" item list
    popup menu option
  + Fixes SF #2027445: Incorrect invalid encoding errors.
  + Fixes "lost" views. View in the cache database that
    are not used anymore will be dropped on startup.
  + Added new Slovakian translation
* Tue Sep  9 2008 cthiel@suse.de
- update to version 1.4.19
  * Fixes a cache limit bug when merging items of feeds with more items than
    the cache allows.
  * Fixes po/LINGUAS which missed "hu".
  * Fixes a bug introduced with 1.4.18 which caused news bins to drop
    everything on startup.
  * Workaround for SF #1995329: Next-Unread item selection doesn't always
    work
  * Removing broken 'updated' state handling.  Manually resetting update
    states didn't work persistently. Also many users confused the 'updated'
    flag with the read status.
  * Added pownce.com social bookmarking support.
* Sun Aug 31 2008 cthiel@suse.de
- switch to xulrunner 190, thanks to Wolfgang Rosenauer!
* Fri Aug 29 2008 cthiel@suse.de
- update to version 1.4.18
  * Fixes SF #1800030: Fix date format problem in non UTF-8 locale for date
    strings representing dates older one week.
  * Fixes a bug that causes the single item removal to have no effect at
    all. This also can cause reappearing of old items and wrong unread
    counts.
  * Fixes the 100%% CPU usage of the previous versions that was cost by
    exorbitant merging costs due to the cache dropping not working anymore
    due to the item removal issue mentioned above.
* Mon Aug  4 2008 cthiel@suse.de
- update to version 1.4.17
  * Changes LUA module loading to use the default module loading function
    provided by LUA 5.1. This solves the problem that the "os" module isn't
    loaded on some setups.
  * New DB cleanup handling that removes stale rows in the "items",
    "itemsets" and "subscription" table.
  * Fixes autocommit warning during migration.
  * Fixes SF #2020621: Can't play Ogg/Vorbis audio enclosures. Now doesn't
    present XSPF for those.
  * Update of French translation
  * Update of Czech translation
  * Added new Hungarian translation
- changes in version 1.4.16b
  * Fixes SF #1990601: schema creation bug introduced in 1.4.16. Only
    affects first installations.
- changes in version 1.4.16
  * Fixed wrong language code of Czech translation.
  * Fixes SF #1920860: crash after memory corruption when parsing feed with
    invalid encoding
  * Build support for XulRunner 1.9
  * Significant speed improvement for the cache conversion necessary when
    upgrading from 1.4.9. Fixes 100%% CPU during startup problem.
  * Fixes comment removal bug.
  * Drops all comments from cache to cleanup stale comments.
  * Changes DB schema to better handle comments during item and subscription
    deletion. This makes the cache version incompatible to 1.4.15!
  * Update of French translation
* Mon Apr 28 2008 cthiel@suse.de
- update to version 1.4.15
  * Fixes assertion when creating subscriptions using the advanced
    subscription dialog.
  * Fixes Debian #433393: subscription not update anymore when number of
    flagged items = cache limit.
  * Fixes OpenSuSE #371307: possible undefined behaviour when decoding
    authentication data.
  * Fixes SF #1912774: news.yv valid feed "is not available"
  * Fixes SF #1874030: build breakage with recent WebKit versions
  * Fixes SF #1919640: segfault when 'Ctrl-R' pressed without selection
  * Merged patch from OpenBSD (SF #1924623) to correctly handle feeds served
    with non-ASCII HTTP headers.
  * Merged patch from Arnold Noronha that fixes deallocation of GdkColor
    instances.
  * Update of Portugese translation
  * New Czech translation
  * Update of Russian translation
  * Fixes Debian #475603: invalid XHTML displayed in HTML view when
    searching (Swedish only).
  * Fixes SF #1940695: crash when using Turkish translation
- changes in version 1.4.14
  * Fixes SQL join when matching item metadata in a search folder.
  * Added workaround for negative search folder unread count values.
  * Fixes Debian #469245: hanging on cache migration from 1.0 when copying
    deprecated named pipe "new_subscription"
* Tue Mar 18 2008 cthiel@suse.de
- update to version 1.4.13
  * WebKitGtk interface updates for SVN r28711.
  * Fixes SF #1886797: crash on format string
  * Fixes SF #1884048: crashes on empty comment feed URI
  * Workaround for Debian #454184: crash on startup when Gecko widget not
    visible.
- changes in version 1.4.12
  * Added support for OPML blogrolls with "xmlURL" (instead of "xmlUrl")
  feed attributes as created by LiveJournal blogroll exports.
  * Fix for missing statusbar signal.
  * Fixes SF #1879861: browser skimming hotkey doesn't work correctly when
    used in search folders.
  * Removes versioned notification plugin soname.
* Thu Jan 24 2008 cthiel@suse.de
- update to version 1.4.11
  * Fixes SF #1795739: Unread count on systray icon is wrong
  * Fixes crash when selecting news bins.
  * Fixes SF #1870052: Crash upon hitting <enter> with no headline selected
  * Fixes SF #1868054: _XOPEN_SOURCE defined incorrectly
  * Fixes SF #1868052: gmtime reentrancy problem
  * Update of European Portugese translation
  * Update of Spanish feed list translation
* Mon Dec 24 2007 cthiel@suse.de
- update to version 1.4.10
  * Fixes SF #1842579: feed:// URI handling broken for URIs without protocol
    part. Such URIs are used by Firefox 3.0
  * Fixes a memory leak in the item list loading duplicate elimination
    handling.
  * Fixes SF #1832389: cache limit causes flipping between old items
  * Fixes SF #1850139: assertion when searching for feed item
  * Fixes broken indication of updated items.
  * Fixes removal of comments along with parent items.  This was broken with
    earlier releases and causes uncontrolled DB file growth.
  * On migration from 1.4.9 or older versions it drops all comment items to
    clean up the database.
  * Update of default feed lists to be distro neutral. Removes Debian/Ubuntu
    feeds.  (patch SF #1843737)
  * Update of Brazilian Portugese translation
  * Added new European Portugese translation
  * Added new European Portugese default feed list
* Thu Dec 13 2007 cthiel@suse.de
- update to version 1.4.9
  * Adds a Ctrl-W binding to close browser tabs.
  * Fixes SF #1836691 core dump when sqlite DB file is already locked
  * Fixes a crash when marking search folders as read.
  * Fixes loose of feed description text after restarts.
  * Fixes impossible use of --version/--help when Liferea is already running
    due to wrong check order.
  * Fixes an assertion when changing search folder rules.
  * Fixes broken negative search folders rules
  * Fixes missing translation of combo boxes in preferences dialog
  * Update of Japanese translation
- changes in version 1.4.8
  * Now never loads duplicates when using recursive folder view. This avoids
    duplicate removal problems when using Mark-All-Read on such a view.
  * Fixes CVE-2005-4791: LD_LIBRARY_PATH problem in Liferea starter script.
  * Fixes SF #1832671: use default update interval even if feed specifies
    one if it is larger than the feed specific one.
  * Fixes failing DB close when terminated by session manager or
    SIGHUP/TERM/INT which causes long startup durations (>30s) on next start
    due to leftover sqlite journal file.
  * Patch SF #1835414 from goyko that improves menu enabling and disabling
    for the "Item" menu options.
  * Updated Italian translation
  * Updated Belorusian Latin translation
  * Correction for Spanish translation
- changes in version 1.4.7
  * Fixes SF #1821179 crash with Catalan locale.
  * Fixes disabled mark-all-read toolbar button when a folder is selected.
  * Fixes SF #1825113 crash when removing folders when child feeds are in
    update.
  * Fixes drag&drop into empty folders.
  * Fixes handling of updated items. Now updated items are replaced and
    marked again appropriately.
  * Fixes problems with search folders with more than one rule.
  * Added kget download manager support SF #1824344.
  * Updated Polish translation
  * Updated French translation
- changes in version 1.4.6
  * Fixes visible markup in "no title" item titles.
  * Fixes SF #1809742 unread count in tray icon not updated properly
  * Fixes Debian #445457 segfaults when clicking on empty folder
  * Fixes security issue that feedlist.opml backup file has permissions 0644
    instead if 0600.
  * Updated Japanese translation
  * Fixes Ubuntu #156303 segfault on mark-all-read
  * Build fix for NetworkManager 0.7.x
  * Fixes SF #1787007: looses user-defined feed titles on updates
- changes in version version 1.4.5b
  * Fixing wrong deallocation that prevents Liferea from working with sqlite
    3.5.x (SF #1811055).
- changes in version 1.4.5
  * Parses Atom links with rel="related" and rel="via" now and displays the
    links in the item header. This makes so called "link blogs" readable
    with Liferea (SF #1784970).
  * Fixes incorrect SQL join for search folders with multiple rules one of
    which is a node title match (SF #1803859)
  * Fixes DnD command line warnings (SF #1799006)
  * Fixes DnD target check to avoid dropping nodes into read-only source sub
    trees.
  * Fixes crash when using "Select File" from the
    advanced subscribtion dialog (SF #1810825)
  * Workaround for loosing data on forced termination.  Liferea now
    reconnects sqlite every 500 write attempts (SF #1791068, SF #1784045).
  * Fixes instant updating of the item count of search folders matching
    flagged items.
  * Adapted WebKit support to changed function names in WebKit SVN.
* Sat Oct  6 2007 cthiel@suse.de
- update to version 1.4.4
  * Removing deprecated "Encoding" entry from
  .desktop file
  * Fixed warnings/errors with "gecko" as program name. Now the correct name
    "liferea" is used.
  * Fixes assertion when cancelling feed updates using the update monitor
    dialog.
  * Fixes Debian #443751: Tries to run scripts to retrieve favicons
  * Fixes SF #1803072: Search folders broken
  * Fixes vertical/horizontal pane position saving when exiting Liferea
    while the mainwindow is not visible.
* Tue Sep 25 2007 cthiel@suse.de
- update to version 1.4.3b
  * Fixes a data loss problem that causes flagged items to be dropped out of
    cache. Normally flagged items are never to be dropped.
- changes in version 1.4.3
  * Fixes a grave bug that caused continuous feed downloads when the default
    update interval is set to 0, which is to mean disabled.
  * Fixes assertions in db_item_check() and db_query_to_sql() for search
    folders that do not have rules.
  * Fixes SF #1798880: problem when using Ctrl-u inside a search folder
    matching unread items.
  * Fixes Debian #430782: better handling of RSS 2.0 LiveJournal feeds which
    use lj: prefix for some HTML elements.
  * Fixes SF #1799476: crash when following links.
- changes in version 1.4.2b
  * Fixes compilation problems of GtkHTML2 rendering.
  * Fixes SF #1798158: problem with 'mark as read' option in popup window
  * Now removes leading/trailing white spaces from feed list node titles.
  * Fixes broken HTTP authentication. Auth info was just not passed with
    HTTP requests.
  * Fixes Debian #442798: update interval values isn't correctly updated.
    Interval unit is lost.
* Thu Sep 13 2007 cthiel@suse.de
- update to version 1.4.2, changes compared to 1.2:
  * Comment feed support: auto-downloading of comments.
  * Sqlite3 database backend for feed content storage.
  * Improved proxy support (better no-proxy support).
  * Duplicate headlines detection.
  * Automatic browser support selection (removed preference)
  * Dropped proprietary popup code in favour of libnotify solution.
  * Improved DBUS support, some new methods.
  * Added support for gwget support as download tool.
- disable gkthml2 support
* Fri Aug 31 2007 maw@suse.de
- Pass -fno-strict-aliasing to gcc as well as to g++.
* Wed Aug  8 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Tue Aug  7 2007 cthiel@suse.de
- added openSUSE News feed (#293690)
* Tue Aug  7 2007 cthiel@suse.de
- exclude Makefile* (#217472)
* Tue Aug  7 2007 cthiel@suse.de
- update to version 1.2.20
  * Update of Spanish translation
  * Fixes a compilation problem on systems without
    getaddrinfo
  * Fixes a bug in the networking code
- changes in version 1.2.19
  * Fixes SF #1741243 which caused endless loops on
    LiveJournal authentication.
  * Added Brazilian-Portugese localized feed list.
- changes in version 1.2.18
  * Fixes some memory leaks
  * Improved manpage
  * Starter script support for $DEBUGGER
  * Fixed XulRunner library root compilation parameter
  * Making the tray icon transparent again when the
  "show new count" option is disabled.
- changes in version 1.2.17
  * Fixes some memory leaks
  * Fixes SF #1731789 "Open Feed" in detailed libnotify
    popup view did not work
  * Fixes SF #1736409 HTTP Digest authentication handling
    to support spaces in quoted value strings.
  * Ignores GNUTLS_E_UNEXPECTED_PACKET_LENGTH (-9)
    errors which seems to happen with GMail feeds.
  * New Czech translation
  * New Basque default feed list
- changes in version 1.2.16
  * Major code reorganisation to minimize the number
    of gettimeofday() calls which caused a lot of CPU
    activity and wakeups on laptops.
  * Fixes "jumpy" behaviour of the HTML view item menu
    in three pane mode. Now the menu is visible
    immediately on rendering.
  * Fixes a bad mistake in the timer code that caused
    a lot of unnecessary wakeups and thereby high power
    consumption on laptops.
  * New Basque translation
- changes in version 1.2.15
  * Better update result processing timer, should cause
    less CPU usage.
  * Increased security: disallowing clicking on file://
    links in the rendering widget, as well as preventing
    from opening such links using the context menu.
  * Fixes unresolved symbol in LUA binding.
  * Fixes broken base URL when selecting items in 3 pane
    mode from folders.
- changes in version 1.2.14
  * Adds network execution priviledges for the XSPF flash applet
    Liferea uses to play MP3 enclosures
  * Allowing HTTP headers with tab character at line start.
  * Fixes a crash when updating the Atom 0.3 GMail feed
  * Update of Japanese translation
- changes in version 1.2.13
  * Fixes a significant memory leak when dropping items
    from cache reported by several users.
  * Changes the new item counting to a simpler counting
    statistic so that on subsequent updates of the same
    feed might present a lower new item number, but which
    is a bit faster.
  * Added new Catalan default feed list
- changes in version 1.2.12b
  * Fix for default feed list filename used with
    Brazilian Portugese translation
  * Update of Brazilian Portugese translation
  * Adds a check to prevent loading of invalid filenames
    of localized feed lists.
- changes in version 1.2.12
  * Workaround for Gentoo bug #116797
  * Fixes possible crash when removing folders with unread items.
  * Updated Spanish translation
  * Added Catalan translation
- changes in version 1.2.11
  * Added scripting hook for program shutdown.
  * Updated French translation
  * Updated Swedish translation
  * Added Swedish default feed list
- changes in version 1.2.10c
  * Reverting fix of 1.2.10 to prevent crashes in the
    Gecko support code when clicking links in the HTML view.
  * Changed feed property label (auto-load link) to match
    real (suboptimal) behaviour when external browser
    is configured.
  * Adds a hot key (Ctrl-L) to mark all feeds as read.
  * Fixes outdated URL in the default feed lists.
  * Fixes syntax errors in some default feed lists.
  * Update of Turkish translation
- changes in version 1.2.10b
  * Fixes a crash when updating a folder recursively
    after marking all items of this folder as read.
  * Update of French translation
- changes in version 1.2.10
  * Added rendering of "creator" metadata attribute.
  * Fixes crash when removing folder with unread items.
  * Fixes links opening up in the configured external browser
    for feeds with enabled "auto load link" setting when the
    "load links in internal browser" preference is not set.
  * Fixes another negative unread count problem.
  * Update of Arabic translation
- changes in version 1.2.9
  * Fixes negative unread count problems introduced with
    the last release.
  * Lowered memory usage by correctly unloading feeds from
    memory after unselecting recursively displayed folders.
  * Improved performance by avoiding unnecessary folder load
    recursions.
  * New preference option that allows enabling the display
    of the number of new items in the tray icon.
  * New preference option that allows to disable minimizing
    to tray when closing the main window.
  * Adding DBUS introspection
  * Update of German translation
- changes in version 1.2.8
  * Adds a DBUS ping function that is used by the
    liferea-add-feed script to check if the program is running.
  * The liferea-add-feed script now starts Liferea if necessary.
  * Added 1x1 pixel filter to adblocking stylesheet.
  * Fixes SF #1668278: error when exporting the feed list
    although the export was successfully completed
  * Fixes SF #1657717: memory leak when stripping DHTML from
    HTML type metadata
  * Updated Italian translation
  * Updated Brazilian Portugese translation
  * New Swedish translation
* Sun Apr  1 2007 ro@suse.de
- added non-english manpage directories to filelist
* Fri Mar 16 2007 sbrabec@suse.cz
- Added c++ packages to BuildRequires.
* Fri Mar  9 2007 sbrabec@suse.cz
- Fixed BuildRequires to enable all features.
- Removed obsolete hicolor icon symlink (#248676).
* Thu Feb 22 2007 cthiel@suse.de
- update to version 1.2.7
  * Fixes in the feed list loading error handling.
  * Now after successful feed list import on startup a feedlist.opml backup
    file will be created.
  * Fixes LUA support detection.
- changes from 1.2.5 to 1.2.6
  * Fixes SF #1654989 that caused crashes when marking duplicate items as
    read/unread
  * Merged patch SF #1646186 by mooonz that improves LUA build support and
    allows compilation against LUA 5.0 and 5.1
  * Update of French translation
  * Update of Japanese translation
  * Conditional display of the feed title when viewing merged item lists so
    that it is clear what the source feed of a displayed item is.
  * The item view header now provides a list of the feeds that contain a
    duplicate of the feed.
  * When changing the read status of an item with duplicates in other feeds
    the read status is propagated to the other item instances.
  * Update of French translation
- changes from 1.2.4 to 1.2.5
  * Disabling GtkHTML2 support for x86_64 platforms.  Maintainers: please do
    discontinue any GtkHTML2 support on such platforms if possible, as it
    cause only trouble!
  * Removed console warning that was given on each startup as long as social
    bookmarking site was not set.
  * Fixes Debian #408475: liferea wrapper script is brittle, depends on $0
  * Fixes a type problem in the Digest authentication that caused crashes on
    AMD64 (SF #1636563)
  * Fixes for Turkish translation
  * Fixes for Arabic translation
  * New Russian translation
- changes from 1.2.3 to 1.2.4
  * Fixes a possible GUI deadlock usually happening when using the Gecko
    rendering during background feed updates.
  * Fixes a problem with relative feed base URLs.
  * Fixes broken "item unselect" script trigger.
  * Update of French translation
  * New Turkish translation
- changes from 1.2.2 to 1.2.3
  * HTML view respects GTK theme colors now.
  * Fixes negative new count values in the mainwindow status bar.
  * Fixes incorrect unread count of parent folder when removing
    subscriptions with unread items.
  * Fixes node info updating when marking read with middle mouse button in
    the feed list.
  * Fixes a bug that caused item loss in news bins.
  * Adds Arabic translation
* Thu Jan 11 2007 cthiel@suse.de
- update to version 1.2.2
  * Fixes folder expansion problem on startup: subfolders were not expanded
    at all.
  * Fixes the broken cache disabled archive mode. Feeds without caching
    should be usable again.
  * Fixes link styles in 2 pane summary mode when used with GtkHTML2.
  * Fixes an effect where items selected from a search folder are rendered
    in summary instead of detailed mode.
  * Memleak patch from Philip Withnall.
- changes from 1.2 to 1.2.1
  * Fixes a bug that prevented column resizing in the item list.
  * Fixes SF #1617434: prevents launching links in internal browser when
    using GtkHTML2.
  * Fixes SF #1620875: loosing feeds after DnD
  * Fixes recursive favicon features which didn't update favicons of feeds
    within folders.
- changes for 1.2
  * Fixes a crash when removing subscriptions.
  * Fixes suboptimal item list updating.
  * Fixes SF #1595486: items whose base URL contained an "=" character are
    not to be displayed at all.
  * Fixes SF #1617081: heavy memory leaking.
  * Suppress unknown metadata type warnings. They are now printed at trace
    level only.
  * Allow flagging by left clicking in the flag column.
  * Simple sorting feature for the item state column.
  * Makes item header links work for GtkHTML2 again.
  * Dropping ns_fm.* code as namespace is not used anymore in any feeds on
    line.
  * Added Slashdot namespace rendering again.
- numerous fixes since 1.0.20
* Thu Jan 11 2007 sbrabec@suse.cz
- Spec file cleanup.
* Thu Jan 11 2007 maw@suse.de
- Move to /usr.
* Wed Dec 20 2006 jhargadon@suse.de
- fixed an issue where liferea was being displayed twice in the
  desktop menu.  (#225609)
* Thu Nov 30 2006 sbrabec@suse.cz
- Fixed xulrunner dependencies for older products.
* Tue Nov  7 2006 sbrabec@suse.cz
- Use exact xulrunner version 181 (#216100).
* Wed Nov  1 2006 jhargadon@suse.de
- fixed a problem with LD_LIBRARY_PATH reported in bug #216105
* Fri Aug 11 2006 btimothy@suse.de
- added two (2) example feeds specific to openSUSE
  * Novell Forge : Community - SUSE LINUX
  * Planet SuSE
  * Fixes BNC #183686
* Tue Aug  8 2006 cthiel@suse.de
- update to version 1.0.20
  * The Mozilla rendering plugin now has the Mozilla library path hard coded
    to ensure to use the correct gtkmozembed library. This also means that
    there is no more searching for gtkmozembed by the start script.  This
    should fix SF #1532011 and SF #1455278.
  * Fixes SF #1529612 which causes Liferea to ignore a HTTP 301 redirect if
    it is followed by a HTTP 304.
* Tue Aug  1 2006 cthiel@suse.de
- update to version 1.0.19
  * Fixes a uninitialized value bug in the lock handling.
  * Adds a DBUS method to change the online state of Liferea
  * Fixes a possible DBUS crash by correctly initializing
    the DBUS thread handling. (SF #1523428)
  * Added a patch which solves three 64bit issue that cause crashes on AMD64
    installations.
  * Fixes some compiler warnings for the Mozilla renderer plugin.
  * Bigger update of the manpage.
* Sat Jul 22 2006 cthiel@suse.de
- update to version 1.0.18
  * Fixes SF #1526078 which caused crashes when accessing RSS 2.0 feeds
    without a channel link.
  * Avoid crashes by checking the content type of responses before parsing
    favicon image data
  * Quoting fix in the liferea start fix to make it run with Bourne shell SF
    [#1526724].
  * Compile flags fix for Solaris where -lresolv was missing SF #1526722.
  * Added a note about the DBUS interface and wrapper script to the manpage.
  * Added a gconf key to disable DBUS if necessary
    (/apps/liferea/disable-dbus).
  * Removed support for DBUS 0.23. Now the minimal DBUS dependency is 0.30.
- changes from 1.0.16 to 1.0.17
  * Added SuSE patches supplied by Christoph Thiel.
  * Fixes a possible uninitialized value in the network authentication code.
  * Partially fixes Debian #378075 reported by Daniel Jacobowitz, which
    caused the unwanted unescaping of URLs when internally launching links
    with the GtkHTML browser module.
* Wed Jul 12 2006 cthiel@suse.de
- remove unneeded liferea-64arch.patch
* Wed Jul 12 2006 cthiel@suse.de
- liferea-1.0.16-xulrunner.patch: make lifera find the xulrunner stuff
* Tue Jul 11 2006 cthiel@suse.de
- update to version 1.0.16
  * dropped obsolete liferea-xulrunner.patch
- changes from 1.0.15 to 1.0.16
  * Workaround for SF #1509741 where GtkHTML2 can cause crashes when
    reducing the zoomlevel when multi-line text is selected.
  * Fixes a significant memory leak as described in SF #1498277
- changes from 1.0.14 to 1.0.15
  * Removing confusing output line from starter script (Debian #372733)
  * Added patch SF #1504171 that fixes the problem of the headline states
    not getting updated after a feed update.
  * Added a workaround for SF #1503029 which crashes when doing HTTP digest
    authentication without a "nonce" field in the authentication data.
- changes 1.0.13 to 1.0.14
  * New wrapper script "liferea-add-feed" for the dbus-send command needed
    to add subscriptions from the command line.
  * Fixes full content display for Atom 0.3 feeds (Debian #366822).
  * Fixes the --mainwindow-state=hidden behaviour.  Until now it had the
    same effect like --mainwindow-state=iconified.
  * Update of Polish translation
  * Fixed some links in the German documentation.
- changes from 1.0.12 to 1.0.13
  * Added a patch to make the tray icon respect the GNOME panel transparency
    setting. This will only work for the most recent GNOME versions.
  * Liferea now calls res_init() to recover from disconnect situations where
    the host was moved to another network.
- changes from 1.0.11 to 1.0.12
  * XulRunner support. Liferea now provides an additional browser module
    that is for running with XulRunner. So now it can work with GtkHTML2,
    Mozilla/Firefox and XulRunner.
- changes from 1.0.10 to 1.0.11
  * Added "ins" and "del" element styles to CSS.  SF patch #1393105
  * The source package now contains a Firefox extension (feedbag.xpi) that
    changes the live bookmarks button so that it will add add subscriptions
    directly to Liferea.
  * Fixes a Atom 1.0 parsing bug when parsing plain text content.
  * Fix for SF #1480051: Avoid adding internal feed list properties when
    exporting the feed list to OPML. Also always adding a text attribute to
    each outline node.
  * Fix for SF #1479930: Liferea exited with assertion when unselecting a
    vfolder that was displayed in 2 pane mode.
- changes from 1.0.9 to 1.0.10
  * Added 64bit library path for Firefox to start script
  * Added fix a timezone parsing problem
  * Added a workaround for a problem caused by installing the gconf schemes
    from earlier Liferea version, which caused a HTML view zoom level of 0.
- changes from 1.0.8 to 1.0.9
  * Patch to prevent the invisible text problem. This happened because the
    schema default values (including the one for text zooming) could not be
    localised.
  * Update of Italian translation
- changes from 1.0.7 to 1.0.8
  * Adaption of style sheets to prevent GtkHTML2 from using the theme color
    for links.
  * Fix for a problem that did prevent opening file:// URLs with anchors in
    GtkHTML2
  * German translation of the user documentation.
  * Update of Swedish translation
- changes from 1.0.6 to 1.0.7
  * Fix crashes relating to file selection.
  * Improves all GTK 2.0 directory selection dialogs.  They no longer show
    the file selection list. It also fixes an issue with loading the last
    dirname part as the filename.
  * New Polish default feed list
  * Update of Polish translation
  * Update of Dutch translation
- changes from 1.0.5 to 1.0.6
  * The schema documentation was updated to add all still undocumented gconf
    keys.
  * Fixes a mismatch between the schema default and the preference
    preselection for the item list time column format option.
  * Update of Polish translation
  * Update of Dutch translation
  * Added Dutch default feed list
  * Added Dutch quick reference
  * Added Japanes quick reference, FAQ & help topics
- changes from 1.0.4 to 1.0.5
  * Added Dutch translation
  * Update of Brazilian Portugese translation
- changes from 1.0.3 to 1.0.4
  * Removes GDK locking to avoid freezing the program when a new browser
    window is created or a flash plugin is used. Note that this only effects
    users of the mozilla renderer and not the gtkhtml2 renderer.
  * When browsing the World Wide Web inside of Liferea, tab titles now
    change to the title of the HTML page being viewed. Also, a similar
    change was made for the location bar.
  * Fixes a crash in the Atom 1.0 parser.
  * Tray icon reports if Liferea is in offline or online mode.
  * Long headlines are now ellipsized when displayed in the item list.
  * Update of Spanish translation
  * Update of German translation
- changes from 1.0.2 to 1.0.3
  * Fixes a problem introduced with 1.0.2 that causes crashes when parsing
    Atom 1.0 feeds without proper type attributes on content tags.
- changes from 1.0.1 to 1.0.2
  * Escapes comma characters in URL so loading websites with such URLs in
    external browsers that use the X remote protocol works. (SF #1404730)
  * Atom 1.0 parsing improvements.
  * Improved zlib decompression support (SF #1411596)
  * Updated mozilla browser module source to allow compilation against
    Firefox 1.5.
- changes from 1.0 to 1.0.1
  * Fixes a compatibility issue with Firefox 1.5 that might cause crashes
    when running with both the Mozilla Suite and Firefox are installed.
  * Removes vfolder nodes when exporting the feed list. (SF #1407742)
* Sat Feb 18 2006 gekker@suse.de
- fixup .desktop file for UI team
* Sat Feb  4 2006 gekker@suse.de
- Fix to also use "." to read next unread message
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 lmichnovic@suse.cz
- updated to version 1.0
- added section clean
- two new patches: liferea-uninitialized_var.patch, liferea-64arch.patch
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Thu Oct 13 2005 ro@suse.de
- use mozilla-devel-packages in nfb
- use xulrunner if others not found
* Thu Sep 29 2005 sbrabec@suse.cz
- Use secure LD_LIBRARY_PATH in wrapper (#118188).
* Tue Aug  2 2005 rodrigo@suse.de
- Updated to 0.9.4.
- Removed part of liferea-warnings.patch already fixed upstream.
- Removed liferea-0.9.2-dbus.patch.
* Mon Jun 20 2005 sbrabec@suse.cz
- Build with mozilla and dbus support.
- Fixed for new dbus.
  http://bugs.gentoo.org/show_bug.cgi?id=91928
* Tue Jun 14 2005 gekker@suse.de
- Initial import of version 0.9.2.
